[MOBY-guts] biomoby commit

Martin Senger senger at pub.open-bio.org
Thu Oct 27 08:55:49 UTC 2005


senger
Thu Oct 27 04:55:48 EDT 2005
Update of /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard
In directory pub.open-bio.org:/tmp/cvs-serv3740/src/main/org/biomoby/service/dashboard

Modified Files:
	AbstractModel.java AbstractPanel.java CommonBoard.java 
	Dashboard.java DashboardPanel.java DataTypesBoard.java 
	PropertyChannel.java RegistrationPanel.java RegistryModel.java 
	RegistryPanel.java 
Added Files:
	DebuggingPanel.java 
Removed Files:
	ConsolePanel.java EventGeneratorPanel.java 
Log Message:


moby-live/Java/src/main/org/biomoby/service/dashboard DebuggingPanel.java,NONE,1.1 AbstractModel.java,1.1,1.2 AbstractPanel.java,1.10,1.11 CommonBoard.java,1.1,1.2 Dashboard.java,1.7,1.8 DashboardPanel.java,1.4,1.5 DataTypesBoard.java,1.2,1.3 PropertyChannel.java,1.4,1.5 RegistrationPanel.java,1.4,1.5 RegistryModel.java,1.7,1.8 RegistryPanel.java,1.12,1.13 ConsolePanel.java,1.5,NONE EventGeneratorPanel.java,1.4,NONE
===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractModel.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractModel.java	2005/09/24 17:54:37	1.1
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractModel.java	2005/10/27 08:55:48	1.2
@@ -44,9 +44,8 @@
  */
 
 public class AbstractModel
-    implements PropertyChangeListener, DashboardProperties {
+    implements DashboardProperties {
 
-    protected PropertyChangeSupport support;
     protected PropertyChannel propertyChannel;
 
     /*********************************************************************
@@ -55,26 +54,11 @@
     protected AbstractModel() {
     }
 
-    /*********************************************************************
-     * Usual constructor that shares support for property changes with
-     * its creator.
-     ********************************************************************/
-    protected AbstractModel (PropertyChangeSupport support) {
-	this.support = support;
-    }
-
-    /**************************************************************************
-     * Here we get notified when a property change happen.
-     **************************************************************************/
-    public void propertyChange (PropertyChangeEvent event) {
-    }
-
     /**************************************************************************
      * Keep shared storage of properties updated in various panels.
      **************************************************************************/
     public void setPropertyChannel (PropertyChannel propertyChannel) {
 	this.propertyChannel = propertyChannel;
-	propertyChannel.addPropertyChangeListener (this);
     }
 
 }

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractPanel.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractPanel.java	2005/10/26 08:05:18	1.10
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/AbstractPanel.java	2005/10/27 08:55:48	1.11
@@ -1,6 +1,6 @@
 // AbstractPanel.java
 //
-//    Created: September 2005
+// Created: September 2005
 //
 // This file is a component of the BioMoby project.
 // Copyright Martin Senger (martin.senger at gmail.com).
@@ -51,10 +51,6 @@
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeEvent;
-import java.beans.PropertyChangeSupport;
-
 import java.io.File;
 import java.util.prefs.Preferences;
 import java.util.Map;
@@ -102,14 +98,13 @@
     protected static final Font TITLE_FONT = new Font ("Serif", Font.BOLD, 20);
     protected static final Color TITLE_FGCOLOR = new Color (12, 55, 241);
 
-    //
+    // sharing events
     protected PropertyChannel propertyChannel;
 
     /*********************************************************************
      * Default constructor (just for the sub-classes).
      ********************************************************************/
     protected AbstractPanel() {
-	support = new PropertyChangeSupport (this);
 	loadIcons();
     }
 
@@ -137,33 +132,11 @@
 	return title;
     }
 
-    /*********************************************************************
-     * Property change stuff
-     ********************************************************************/
-    protected PropertyChangeSupport support;
-
-    public void addPropertyChangeListener (PropertyChangeListener l) {
-        if (support != null)
-	    support.addPropertyChangeListener(l);
-    }
-
-    public void removePropertyChangeListener (PropertyChangeListener l) {
-        if (support != null)
-	    support.removePropertyChangeListener(l);
-    }
-
-    /**************************************************************************
-     * Here we get notified when a property change happens.
-     **************************************************************************/
-    public void propertyChange (PropertyChangeEvent event) {
-    }
-
     /**************************************************************************
-     * Remember a property channel and register itself to it as a listener.
+     * Remember the property channel.
      **************************************************************************/
     protected void setPropertyChannel (PropertyChannel propertyChannel) {
 	this.propertyChannel = propertyChannel;
-	propertyChannel.addPropertyChangeListener (this);
     }
 
     //

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/CommonBoard.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.7 -r1.8
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/Dashboard.java	2005/10/25 09:02:07	1.7
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/Dashboard.java	2005/10/27 08:55:48	1.8
@@ -51,7 +51,6 @@
     implements DashboardPanel, ChangeListener {
 
     private JComponent dashboard;
-    private StatusBar statusBar;
     private DashboardHeader header;
     public static boolean useLoadMonitor = true;
     protected JTabbedPane tabbedPane;
@@ -89,7 +88,6 @@
 	loadPanels();
 	propertyChannel = new PropertyChannel();
 	dashboard = getComponent (propertyChannel);
-	connectPanels();
     }
 
     /**************************************************************************
@@ -106,21 +104,6 @@
     }
 
     /**************************************************************************
-     * Connect all available Dashboard panels: a) together, and b)
-     * with the status bar. TBD: It changed... It uses now a PropertyChannel...
-     **************************************************************************/
-    public void connectPanels() {
-	for (int i = 0; i < panels.length; i++) {
-// 	    for (int j = 0; j < i; j++)
-// 		panels[i].addPropertyChangeListener (panels[j]);
-// 	    for (int j = i+1; j < panels.length; j++)
-// 		panels[i].addPropertyChangeListener (panels[j]);
-	    if (statusBar != null)
-		panels[i].addPropertyChangeListener (statusBar);
-	}
-    }
-
-    /**************************************************************************
      * Show the main frame.
      **************************************************************************/
     public void show() {
@@ -212,7 +195,8 @@
 			       panels[i].getIcon(),
 			       panels[i].getComponent (propertyChannel));
 	}
-        statusBar = getStatusBar();
+        StatusBar statusBar = getStatusBar();
+	propertyChannel.addPropertyChangeListener (statusBar);
 
 	if (useLoadMonitor)
 	    ProgressView.monitor.destroy();
@@ -302,24 +286,6 @@
 
     /**************************************************************************
      *
-     **************************************************************************/
-    public void addPropertyChangeListener (PropertyChangeListener listener) {
-    }
-
-    /**************************************************************************
-     *
-     **************************************************************************/
-    public void removePropertyChangeListener(PropertyChangeListener listener) {
-    }
-
-    /**************************************************************************
-     *
-     **************************************************************************/
-    public void propertyChange (PropertyChangeEvent event) {
-    }
-
-    /**************************************************************************
-     *
      * An entry point...
      *
      **************************************************************************/

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DashboardPanel.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DashboardPanel.java	2005/09/24 17:51:51	1.4
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DashboardPanel.java	2005/10/27 08:55:48	1.5
@@ -29,7 +29,7 @@
  */
 
 public interface DashboardPanel
-    extends PropertyChangeListener, DashboardProperties {
+    extends DashboardProperties {
 
     /**************************************************************************
      * Return a graphical representation of this panel. <p>
@@ -70,20 +70,20 @@
      **************************************************************************/
     Icon getIcon();
 
-    /**************************************************************************
-     * Add a PropertyChangeListener to the listener list of a
-     * panel. All listeners will be notified if this panel changes
-     * some property. <p>
-     *
-     * The panel should document what properties can fire - but at the
-     * moment it is not part of its interface. <p>
-     *
-     **************************************************************************/
-    void addPropertyChangeListener (PropertyChangeListener listener);
-
-    /**************************************************************************
-     * Remove a PropertyChangeListener.
-     **************************************************************************/
-    void removePropertyChangeListener(PropertyChangeListener listener);
+//     /**************************************************************************
+//      * Add a PropertyChangeListener to the listener list of a
+//      * panel. All listeners will be notified if this panel changes
+//      * some property. <p>
+//      *
+//      * The panel should document what properties can fire - but at the
+//      * moment it is not part of its interface. <p>
+//      *
+//      **************************************************************************/
+//     void addPropertyChangeListener (PropertyChangeListener listener);
+
+//     /**************************************************************************
+//      * Remove a PropertyChangeListener.
+//      **************************************************************************/
+//     void removePropertyChangeListener(PropertyChangeListener listener);
 
 }

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DataTypesBoard.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.4 -r1.5
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/PropertyChannel.java	2005/10/27 04:15:23	1.4
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/PropertyChannel.java	2005/10/27 08:55:48	1.5
@@ -10,6 +10,9 @@
 
 import org.tulsoft.shared.UUtils;
 
+import org.apache.commons.logging.LogFactory;
+import org.apache.commons.logging.Log;
+
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeSupport;
@@ -30,10 +33,17 @@
  *
  * </ul><p>
  *
- * Obviously, there are some properties that do not make sense to be
- * stored here: the short-lived properties, such as progress bar
- * change events. Such messages can be delivered in an ordinary way
- * via property change listeners. <p>
+ * Additionally, it also serves as a PropertyChangeSupport object: it
+ * can register and deregister PropertyChangeListeners, and it can
+ * fire an event to them on behave of other objects. The other objects
+ * either identify themselves (see method {@link
+ * #fire(Object,String,Object}), or use this channel for firing
+ * anonymous messages (see method {@link #fire(String,Object)}) - in
+ * which case the message source will be this class. <p>
+ *
+ * The fired events are also stored here - under their names. That's
+ * mean that you can always get the last event of a particular
+ * name. <p>
  *
  * The panels/models are sending here properties by calling method
  * <tt>put</tt>. If we find, in the future, that sending properties
@@ -52,6 +62,9 @@
 public class PropertyChannel
     extends Hashtable {
 
+    private static Log log = LogFactory.getLog (PropertyChannel.class);
+    private PropertyChangeSupport support;
+
     /*********************************************************************
      * Default constructor.
      ********************************************************************/
@@ -62,10 +75,13 @@
 
     /*********************************************************************
      * Maps the specified key to the specified value in this
-     * hashtable. Neither the key nor the value can be null. Remember
-     * the given value (do the same as an ordinary Hashtable does),
-     * <b>and</b> propagate it by firing a property change event (this
-     * is called a <em>channel push</em> style). <p>
+     * hashtable. Neither the key nor the value can be null. <p>
+     *
+     * The given value, apart from being stored, is also propagated by
+     * firing a property change event (this is called a <em>channel
+     * push</em> style). The event is anonymous. If you need to send
+     * the source of the message to the listeners, use instead {@link
+     * #put(Object,Object,Object)}. <p>
      *
      * @param key the hashtable key
      * @param value the value
@@ -74,7 +90,29 @@
      ********************************************************************/
     public Object put (Object key, Object value) {
 	Object previous = super.put (key, value);
-	support.firePropertyChange (key.toString(), null, value);
+	fire (key.toString(), value);
+	return previous;
+    }
+
+    /*********************************************************************
+     * Maps the specified key to the specified value in this
+     * hashtable. Neither the key nor the value can be null. <p>
+     *
+     * The given value, apart from being stored, is also propagated by
+     * firing a property change event (this is called a <em>channel
+     * push</em> style). The event contains also its 'source'. For
+     * anonymously sent events, use instead {@link
+     * #put(Object,Object)}. <p>
+     *
+     * @param source that initiated this event
+     * @param key the hashtable key
+     * @param value the value
+     * @return the previous value of the specified key in this
+     * hashtable, or null if it did not have one
+     ********************************************************************/
+    public Object put (Object source, Object key, Object value) {
+	Object previous = super.put (key, value);
+	fire (source, key.toString(), value);
 	return previous;
     }
 
@@ -99,18 +137,69 @@
     }
 
     /*********************************************************************
-     * Property change stuff
+     * Fire an event to any registered listeners. The source of this
+     * event will be this class. <p>
+     *
+     * @param key is a name of the fired event
+     * @param value is a value associated with this event
      ********************************************************************/
-    protected PropertyChangeSupport support;
+    public void fire (String key, Object value) {
+	if (log.isDebugEnabled())
+	    logDebug (null, key, value);
+	support.firePropertyChange (key.toString(), null, value);
+    }
 
+    /*********************************************************************
+     * Fire an event to any registered listeners. The source of this
+     * event will be this class. <p>
+     *
+     * @param source that initiated the event
+     * @param key is a name of the fired event
+     * @param value is a value associated with this event
+     ********************************************************************/
+    public void fire (Object source, String key, Object value) {
+	if (log.isDebugEnabled())
+	    logDebug (source, key, value);
+	support.firePropertyChange
+	    (new PropertyChangeEvent (source, key.toString(), null, value));
+    }
+
+    /*********************************************************************
+     * Register listeners.
+     ********************************************************************/
     public void addPropertyChangeListener (PropertyChangeListener l) {
         if (support != null)
 	    support.addPropertyChangeListener(l);
     }
 
+    /*********************************************************************
+     * Unregister listeners.
+     ********************************************************************/
     public void removePropertyChangeListener (PropertyChangeListener l) {
         if (support != null)
 	    support.removePropertyChangeListener(l);
     }
 
+    /*********************************************************************
+     * Log a debug message.
+     ********************************************************************/
+    protected void logDebug (Object source, String key, Object value) {
+
+	StringBuffer buf = new StringBuffer (100);
+	if (source != null) {
+	    buf.append ("[");
+	    if (source instanceof DashboardPanel)
+		buf.append ( ((DashboardPanel)source).getName() );
+	    else
+		buf.append (source.getClass().getName());
+	    buf.append ("] ");
+	}
+	buf.append (key);
+	buf.append (": ");
+        if (value != null)
+	    buf.append (value.toString());
+		
+	log.debug (buf);
+    }
+
 }

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistrationPanel.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistrationPanel.java	2005/10/26 08:05:18	1.4
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistrationPanel.java	2005/10/27 08:55:48	1.5
@@ -50,8 +50,6 @@
 import java.awt.event.MouseListener;
 import java.awt.event.MouseAdapter;
 
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeEvent;
 import java.util.Map;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -99,12 +97,6 @@
     + " by selecting first a data type, then right-click gives you menu.";
 
     /*********************************************************************
-     * propertyChange()
-     ********************************************************************/
-    public void propertyChange (PropertyChangeEvent e) {
-    }
-
-    /*********************************************************************
      * Default constructor.
      ********************************************************************/
     public RegistrationPanel() {
@@ -120,7 +112,7 @@
 	    if (propertyChannel.containsKey (DP_REGISTRY_MODEL)) {
 		registryModel = (RegistryModel)propertyChannel.get (DP_REGISTRY_MODEL);
 	    } else {
-		registryModel = new RegistryModel (support);
+		registryModel = new RegistryModel();
 		propertyChannel.put (DP_REGISTRY_MODEL, registryModel);
 	    }
 	    registryModel.setPropertyChannel (propertyChannel);
@@ -185,7 +177,7 @@
 	DataTypesBoard dataTypesBoard =
 	    new DataTypesBoard (registryModel,
 				console,
-				support,
+				propertyChannel,
 				new CustomDataTypesTree (registryModel, console));
 	dataTypesBoard.updateTree (CommonTree.SORTED_BY_NAME);
 
@@ -225,7 +217,7 @@
     }
 
     /**************************************************************************
-     * Panel to register a data type.
+     * Panel to register a service.
      **************************************************************************/
     protected JPanel getServiceRegistration() {
 
@@ -235,7 +227,7 @@
     }
 
     /**************************************************************************
-     * Panel to register a data type.
+     * Panel to register a namespace.
      **************************************************************************/
     protected JPanel getNamespaceRegistration() {
 

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryModel.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryModel.java	2005/10/26 08:05:18	1.7
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryModel.java	2005/10/27 08:55:48	1.8
@@ -52,14 +52,6 @@
 	super();
     }
 
-    /*********************************************************************
-     * Usual constructor that shares support for property changes with
-     * its creator.
-     ********************************************************************/
-    public RegistryModel (PropertyChangeSupport support) {
-	super (support);
-    }
-
     /**************************************************************************
      * Return an endpoint (a stringified URL) of a default Moby
      * registry.

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryPanel.java,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryPanel.java	2005/10/27 04:15:23	1.12
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RegistryPanel.java	2005/10/27 08:55:48	1.13
@@ -48,8 +48,6 @@
 import java.awt.event.MouseListener;
 import java.awt.event.MouseAdapter;
 
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeEvent;
 import java.util.Map;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -82,16 +80,6 @@
     CommonConsole console;
 
     /*********************************************************************
-     * propertyChange()
-     ********************************************************************/
-    public void propertyChange (PropertyChangeEvent e) {
-//         String prop = e.getPropertyName();
-//         String newVal = (String)e.getNewValue();
-//         if (newVal == null) return;   // no interest in non-defined  new values
-//         if (prop == null) return;     // no interest in non-specific changes
-    }
-
-    /*********************************************************************
      * Default constructor.
      ********************************************************************/
     public RegistryPanel() {
@@ -107,7 +95,7 @@
 	    if (propertyChannel.containsKey (DP_REGISTRY_MODEL)) {
 		registryModel = (RegistryModel)propertyChannel.get (DP_REGISTRY_MODEL);
 	    } else {
-		registryModel = new RegistryModel (support);
+		registryModel = new RegistryModel();
 		propertyChannel.put (DP_REGISTRY_MODEL, registryModel);
 	    }
 	    registryModel.setPropertyChannel (propertyChannel);
@@ -134,7 +122,7 @@
 	NamespacesTree namespacesTree = new NamespacesTree();
 	DataTypesBoard dataTypesBoard = new DataTypesBoard (registryModel,
 							    console,
-							    support);
+							    propertyChannel);
 	dataTypesBoard.updateTree (CommonTree.SORTED_BY_NAME);
 
 	JSplitPane split1 = new JSplitPane (JSplitPane.HORIZONTAL_SPLIT,

rcsdiff: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RCS/ConsolePanel.java,v: No such file or directory

rcsdiff: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/RCS/EventGeneratorPanel.java,v: No such file or directory




More information about the MOBY-guts mailing list
diff -u -r1.1 -r1.2
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/CommonBoard.java	2005/10/22 01:38:04	1.1
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/CommonBoard.java	2005/10/27 08:55:48	1.2
@@ -20,7 +20,6 @@
 import java.awt.event.ActionListener;
 import java.awt.GridBagLayout;
 import java.awt.GridBagConstraints;
-import java.beans.PropertyChangeSupport;
 
 /**
  * This is a simple graphical widget combining together a tree (a
@@ -31,9 +30,9 @@
  *
  * It is also a listener of events notifying about the loading
  * process.  It reflects this events appropriately in the progress
  * bar, and in some cases it propagates these events as
  * property-change events further (usually they are caught and
  * displayed in Dashboard's status bar). <p>
  *
  * @author <A HREF="mailto:martin.senger at gmail.com">Martin Senger</A>
  * @version $Id$
@@ -44,7 +43,7 @@
     implements NotificationListener {
 
     protected RegistryModel model;
-    protected PropertyChangeSupport support;
+    protected PropertyChannel channel;
 
     // components
     protected JLabel treeTitle;
@@ -56,13 +55,13 @@
      * Constructor. <p>
      *
      * @param model gives access to a Biomoby registry
      * @param support is used to fire property-change events
      ********************************************************************/
     protected CommonBoard (RegistryModel model,
-			   PropertyChangeSupport support) {
+			   PropertyChannel channel) {
 	this.model = model;
 	this.model.addNotificationListener (this);
-	this.support = support;
+	this.channel = channel;
 	treeTitle = new JLabel ("");
     }
 
@@ -31,9 +30,9 @@
  * It is also a listener of events notifying about the loading
  * process.  It reflects this events appropriately in the progress
- * bar, and in some cases it propagates these events as
- * property-change events further (usually they are caught and
- * displayed in Dashboard's status bar). <p>
+ * bar, and in some cases it propagates these events to the property
+ * channel (usually they are caught and displayed in Dashboard's
+ * status bar). <p>
  *
  * @author <A HREF="mailto:martin.senger at gmail.com">Martin Senger</A>
@@ -56,13 +55,13 @@
      *
      * @param model gives access to a Biomoby registry
-     * @param support is used to fire property-change events
+     * @param channel is used to fire property-change events
      ********************************************************************/
     protected CommonBoard (RegistryModel model,

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/Dashboard.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.2 -r1.3
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DataTypesBoard.java	2005/10/23 19:00:24	1.2
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/DataTypesBoard.java	2005/10/27 08:55:48	1.3
@@ -10,11 +10,8 @@
 
 import org.biomoby.shared.event.NotificationEvent;
 import org.biomoby.shared.event.Notifier;
-
 import org.tulsoft.shared.UUtils;
 
-import java.beans.PropertyChangeSupport;
-
 /**
  * This is a simple graphical widget combining together a tree (a
  * subclass of {@link org.biomoby.service.dashboard.CommonTree}) and a
@@ -35,20 +32,28 @@
      *
      * @param model gives access to a Biomoby registry
      * @param console displayed items selected in the tree
      * @param support is used to fire property-change events
      ********************************************************************/
     public DataTypesBoard (RegistryModel model,
 			   CommonConsole console,
-			   PropertyChangeSupport support) {
-	this (model, console, support,
+			   PropertyChannel channel) {
+	this (model, console, channel,
 	      new DataTypesTree (model, console));
     }
 
+    /*********************************************************************
+     * Constructor. <p>
+     *
+     * @param model gives access to a Biomoby registry
+     * @param console displayed items selected in the tree
+     * @param channel is used to fire property-change events
+     * @param customTree allows to plug user-defined tree component
+     ********************************************************************/
     public DataTypesBoard (RegistryModel model,
 			   CommonConsole console,
-			   PropertyChangeSupport support,
+			   PropertyChannel channel,
 			   CommonTree customTree) {
-	super (model, support);
+	super (model, channel);
 	tree = customTree;
 	createItself();
     }
@@ -68,7 +73,7 @@
 	    calibrateProgressBar (UUtils.toInt (event.getMessage()));
 	    break;
  	case Notifier.DATA_TYPE_LOADING:
-	    support.firePropertyChange (DashboardProperties.DP_STATUS_MSG, null, event.getMessage());
+	    channel.fire (DashboardProperties.DP_STATUS_MSG, event.getMessage());
 	    break;
  	case Notifier.DATA_TYPE_LOADED:
 	    addToProgressBar();
@@ -76,7 +81,7 @@
  	case Notifier.DATA_TYPES_END:
  	case Notifier.DATA_TYPES_CANCELLED:
  	case Notifier.DATA_TYPES_RESET:
-	    support.firePropertyChange (DashboardProperties.DP_STATUS_MSG, null, "Done");
+	    channel.fire (DashboardProperties.DP_STATUS_MSG, "Done");
 	    removeProgressBar();
 	    break;
 	}
@@ -35,20 +32,28 @@
      * @param model gives access to a Biomoby registry
      * @param console displayed items selected in the tree
-     * @param support is used to fire property-change events
+     * @param channel is used to fire property-change events
      ********************************************************************/
     public DataTypesBoard (RegistryModel model,

===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/service/dashboard/PropertyChannel.java,v
retrieving revision 1.4
retrieving revision 1.5